import 'package:cached_network_image/cached_network_image.dart';
import 'package:textreader/Utils/Constants/AssetConstants.dart';
import 'package:textreader/Utils/Constants/ColorConstants.dart';
import 'package:flutter/material.dart';
import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:flutter_svg/flutter_svg.dart';
import 'package:shimmer/shimmer.dart';

Widget appNetworkImage(String url, double width, double height, BoxFit boxFit,
    {Color imageColor,
    Color svgColor,
    bool showLoadingShimmers = false,
    bool showLoading = true,
    bool showErrorWidget = true,
    Color svgBackgroundColor,
    BoxFit svgBoxFit}) {
  return (url != null && url.isNotEmpty && url.length > 4)
      ? kIsWeb
          ? Image.network(
              url,
              fit: boxFit,
    width: width,
    height: height,
    color: imageColor,
            )
          : url.substring(url.length - 3) == 'svg'
              ? Material(
                  color: svgBackgroundColor ?? ColorConstants.transparent,
                  child: SvgPicture.network(
                    url ?? "",
                    fit: svgBoxFit ?? boxFit,
                    width: width,
                    color: svgColor,
                    height: height,
                    placeholderBuilder: (BuildContext context) =>
                        showLoadingShimmers
                            ? Shimmer.fromColors(
                                direction: ShimmerDirection.ltr,
                                baseColor: Colors.grey[300],
                                highlightColor: Colors.grey[100],
                                child: Container(
                                  color: ColorConstants.white,
                                ))
                            : Center(
                                child: CircularProgressIndicator()
                                // AppLoader(
                                //   strokeWidth: 1.5,
                                // ),
                              ),
                  ),
                )
              : CachedNetworkImage(
                  fit: boxFit,
                  imageUrl: url ?? "",
                  width: width,
                  color: imageColor,
                  height: height,
                  progressIndicatorBuilder: (context, url, downloadProgress) =>
                      showLoading
                          ? showLoadingShimmers
                              ? Shimmer.fromColors(
                                  direction: ShimmerDirection.ltr,
                                  baseColor: Colors.grey[300],
                                  highlightColor: Colors.grey[100],
                                  child: Container(
                                    color: ColorConstants.white,
                                  ))
                              : Center(
                                  child: CircularProgressIndicator()
                                //   AppLoader(
                                //   value: downloadProgress.progress,
                                //   strokeWidth: 1.5,
                                // )
                      )
                          : SizedBox(),
                  errorWidget: (context, url, error) => showErrorWidget
                      ? Image.asset(
                          AssetConstants.appIcon,
                          height: height,
                          width: width,
                        )
                      : SizedBox(),
                )
      : SizedBox();
}
