import 'package:textreader/Utils/Constants/ColorConstants.dart';
import 'package:flutter/material.dart';

class CustomTextFormField extends StatelessWidget {
  final String hintText;
  final String obscureCharacter;
  final bool isEnable, isObscure;
  final TextInputType inputType;
  final TextEditingController controller;
  final FocusNode node;
  final Function validator, onFieldSubmit, onChange;
  final TextInputAction inputAction;
  final bool readOnly;
  final Widget suffixWidget, prefixWidget;
  final Function() onTap;
  final VoidCallback onPressedLeadingIcon;
  final String labelText;
  final double padding;
  final Color fillerColor;
  final int maxLines;
  final String initialValue;
  final Color cursorColor;
  final int numberLength;

  CustomTextFormField(
      {this.validator,
        this.initialValue,
        this.fillerColor,
        this.cursorColor,
        this.numberLength,
        this.inputAction,
        this.isEnable = true,
        this.isObscure = false,
        this.obscureCharacter,
        this.onFieldSubmit,
        this.prefixWidget,
        this.hintText,
        this.inputType,
        this.controller,
        this.node,
        this.onChange,
        this.onTap,
        this.suffixWidget,
        this.readOnly = false,
        this.onPressedLeadingIcon,
        this.labelText,
        this.maxLines = 1,
        this.padding = 0.0});

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        TextFormField(
          style: TextStyle(fontSize: 16.0, color: Colors.white),
          cursorColor: cursorColor ?? Colors.black,
          onTap: onTap,
          autofocus: false,
          enabled: isEnable,
          obscureText: isObscure,
          obscuringCharacter: obscureCharacter??"*",
          focusNode: node,
          onFieldSubmitted: onFieldSubmit,
          initialValue: initialValue,
          controller: controller,
          textInputAction: inputAction,
          keyboardType: inputType,
          maxLines: maxLines,
          readOnly: readOnly,
          maxLength: numberLength,
          decoration: InputDecoration(
            prefixIcon: prefixWidget,
            fillColor: fillerColor??ColorConstants.transparent,
              counterStyle: TextStyle(color: ColorConstants.transparent),
              suffixIcon: suffixWidget ?? null,
              hintText: hintText,
              labelText: labelText,
              labelStyle: TextStyle(color: ColorConstants.appLabelColor, fontSize: 18.0),
              hintStyle: TextStyle(color: Colors.white, fontSize: 16.0),
              border: OutlineInputBorder(
                borderSide: BorderSide(color: ColorConstants.blue),
                borderRadius: BorderRadius.all(Radius.circular(8))
              ),
              enabledBorder: OutlineInputBorder(
                borderSide: BorderSide(color: ColorConstants.white),
                  borderRadius: BorderRadius.all(Radius.circular(8))
              ),
              focusedBorder: OutlineInputBorder(
                borderSide: BorderSide(color: ColorConstants.white),
                  borderRadius: BorderRadius.all(Radius.circular(8))
              ),
              errorBorder: OutlineInputBorder(
                borderSide: BorderSide(color: Colors.red),
                  borderRadius: BorderRadius.all(Radius.circular(8))
              ),
              focusedErrorBorder: OutlineInputBorder(
                borderSide: BorderSide(color: Colors.white),
                  borderRadius: BorderRadius.all(Radius.circular(8))
              ),
              errorStyle: TextStyle(color: Colors.white, height: 1.1),
              errorMaxLines: 3,
              // contentPadding: EdgeInsets.only(left: 10.0, top: padding),
              // fillColor: Colors.white,
              filled: true),
          validator: validator,
          onChanged: onChange,
          onSaved: (String val) {
            controller.text = val;
          },
        ),
        // suffixWidget != null
        //     ? Align(alignment: Alignment.centerRight, child: suffixWidget)
        //     : SizedBox()
      ],
    );
  }
}

