import 'package:textreader/Utils/Constants/ColorConstants.dart';
import 'package:flutter/material.dart';

class CustomTextFormFieldWithBorder extends StatelessWidget {
  final String hintText;
  final String obscureCharacter;
  final bool isEnable, isObscure;
  final TextInputType inputType;
  final TextEditingController controller;
  final FocusNode node;
  final Function validator, onFieldSubmit, onChange;
  final TextInputAction inputAction;
  final bool readOnly;
  final Widget suffixWidget, prefixWidget;
  final Function() onTap;
  final VoidCallback onPressedLeadingIcon;
  final String labelText;
  final double padding;
  final Color fillerColor;
  final int maxLines;
  final String initialValue;
  final Color cursorColor;
  final int numberLength;

  CustomTextFormFieldWithBorder(
      {this.validator,
        this.initialValue,
        this.fillerColor,
        this.cursorColor,
        this.numberLength,
        this.inputAction,
        this.isEnable = true,
        this.isObscure = false,
        this.obscureCharacter,
        this.onFieldSubmit,
        this.prefixWidget,
        this.hintText,
        this.inputType,
        this.controller,
        this.node,
        this.onChange,
        this.onTap,
        this.suffixWidget,
        this.readOnly = false,
        this.onPressedLeadingIcon,
        this.labelText,
        this.maxLines = 1,
        this.padding = 0.0});

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      style: TextStyle(fontSize: 16.0, color: Colors.black),
      cursorColor: cursorColor ?? Colors.black,
      onTap: onTap,
      autofocus: false,
      enabled: isEnable,
      obscureText: isObscure,
      obscuringCharacter: obscureCharacter??"1",
      focusNode: node,
      onFieldSubmitted: onFieldSubmit,
      initialValue: initialValue,
      controller: controller,
      textInputAction: inputAction,
      keyboardType: inputType,
      maxLines: maxLines,
      readOnly: readOnly,
      maxLength: numberLength,
      decoration: InputDecoration(
          fillColor: fillerColor??ColorConstants.transparent,
          counterStyle: TextStyle(color: ColorConstants.transparent),
          suffixIcon: suffixWidget ?? null,
          hintText: hintText,
          labelText: labelText,
          labelStyle: TextStyle(color: ColorConstants.appLabelColor, fontSize: 16.0),
          hintStyle: TextStyle(color: Colors.black45, fontSize: 15.0),
          border: OutlineInputBorder(
            borderSide: BorderSide(color: ColorConstants.grey,width: 1.5),
          ),
          enabledBorder: OutlineInputBorder(
            borderSide: BorderSide(color: ColorConstants.grey,width: 1.5),
          ),
          focusedBorder: OutlineInputBorder(
            borderSide: BorderSide(color: ColorConstants.white),
          ),
          errorBorder: OutlineInputBorder(
            borderSide: BorderSide(color: Colors.red),
          ),
          focusedErrorBorder: OutlineInputBorder(
            borderSide: BorderSide(color: Colors.white),
          ),
          errorStyle: TextStyle(color: Colors.white, height: 1.1),
          errorMaxLines: 3,
         contentPadding: EdgeInsets.only(left: 15.0, top: padding),
          // fillColor: Colors.white,
          filled: true),
      validator: validator,
      onChanged: onChange,
      onSaved: (String val) {
        controller.text = val;
      },
    );
  }
}

