
import 'package:flutter/material.dart';
import 'package:page_transition/page_transition.dart';
import 'package:textreader/UI/AppHomeUI/AppHomeUI.dart';
import 'package:textreader/UI/SplashUI/SplashUI.dart';
import 'package:textreader/UI/TextDetailandSpeechUI/TextDetailandSpeechUI.dart';
import 'package:textreader/UI/onBoardingUI/onBoradingScreen.dart';
import 'package:textreader/Utils/Constants/RouteConstants.dart';
import '../Utils/Globals.dart' as globals;

class RouteGenerator {
  static Route<dynamic> generateRoute(RouteSettings settings) {
    final animationDuration =
        Duration(milliseconds: globals.pageTransitionDuration);
    final routeArgs = settings.arguments;
    switch (settings.name) {
      case RouteConstants.initialRoute:
        return PageTransition(
            child: AppSplashUI(),
            type: PageTransitionType.fade,
            duration: animationDuration);
      case RouteConstants.onBoardingUI:
        return PageTransition(
            child: OnBoardingScreenUI(),
            type: PageTransitionType.rightToLeft,
            duration: animationDuration);
      case RouteConstants.appHomeUI:
        return PageTransition(
            child: AppHomeUI(),
            type: PageTransitionType.rightToLeft,
            duration: animationDuration);
      case RouteConstants.textDetailandSpeechUI:
        return PageTransition(
            child: TextDetailandSpeechUI(),
            type: PageTransitionType.rightToLeft,
            duration: animationDuration);
      default:
        return _errorRoute();
    }
  }

  static Route<dynamic> _errorRoute() {
    return MaterialPageRoute(builder: (_) {
      return Scaffold(
        appBar: AppBar(
          title: Text('Error'),
        ),
        body: Center(
          child: Text('ERROR'),
        ),
      );
    });
  }
}
