import 'dart:io';

import 'package:firebase_ml_vision/firebase_ml_vision.dart';
import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:provider/provider.dart';
import 'package:textreader/Components/showToast/showToast.dart';
import 'package:textreader/Provider/ImageProvider/ImageProvider.dart';
import 'package:textreader/Provider/SelectFileDetailProvider/SelectFileDetailProvider.dart';
import 'package:textreader/Utils/Constants/ColorConstants.dart';
import 'package:textreader/Utils/Constants/RouteConstants.dart';

class galleryOrCameraImageToText {
  openBottomSheet(context) {
    showModalBottomSheet(
        isDismissible: false,
        context: context,
        builder: (BuildContext bc) {
          return Container(
            child: Wrap(
              children: <Widget>[
                Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    InkWell(
                      onTap: () => Navigator.of(context).pop(),
                      child: Icon(
                        Icons.arrow_drop_down_sharp,
                        color: ColorConstants.appButtonColor,
                        size: 80,
                      ),
                    )
                  ],
                ),
                ListTile(
                    leading: const Icon(
                      Icons.camera,
                      color: ColorConstants.appButtonColor,
                    ),
                    title: const Text('From CAMERA'),
                    onTap: () async {
                      imgFrom(ImageSource.camera, context);
                      Navigator.of(context).pop();
                    }),
                ListTile(
                  leading: const Icon(
                    Icons.image_outlined,
                    color: ColorConstants.appButtonColor,
                  ),
                  title: const Text('From INTERNAL STORAGE'),
                  onTap: () async {
                    imgFrom(ImageSource.gallery, context);
                    Navigator.of(context).pop();
                  },
                ),
              ],
            ),
          );
        });
  }

  Future imgFrom(ImageSource imageSource, BuildContext context) async {
    var getImageProvider =
        Provider.of<GetImageProvider>(context, listen: false);
    var selectFileDetailProvider =
        Provider.of<SelectFileDetailProvider>(context, listen: false);
    selectFileDetailProvider.setLoading = true;
    selectFileDetailProvider.scanText = '';
    ImagePicker picker = ImagePicker();
    PickedFile pickedFile;
    pickedFile = await picker.getImage(
      source: imageSource,
    );
    if (pickedFile != null) {
      getImageProvider.setImage = File(pickedFile.path);
      selectFileDetailProvider.setFileName = pickedFile.path.split('/').last;
      final FirebaseVisionImage visionImage =
          FirebaseVisionImage.fromFile(File(pickedFile.path));
      final TextRecognizer textRecognizer =
          FirebaseVision.instance.textRecognizer();
      final VisionText visionText =
          await textRecognizer.processImage(visionImage);
      for (TextBlock block in visionText.blocks) {
        for (TextLine line in block.lines) {
          selectFileDetailProvider.scanText += line.text + '\n';
        }
      }
      selectFileDetailProvider.setLoading = false;
      if (selectFileDetailProvider.scanText.isNotEmpty) {
        Navigator.of(context)
            .pushNamed(RouteConstants.textDetailandSpeechUI);
      } else {
        showToast("File isn't Select");
      }
    } else {
      selectFileDetailProvider.setLoading = false;
    }
  }
}
