import 'package:flutter/material.dart';
import 'package:image_picker/image_picker.dart';
import 'package:provider/provider.dart';
import 'package:textreader/Components/AppHeader/AppHeader.dart';
import 'package:textreader/Components/Loaders/AppLoader.dart';
import 'package:textreader/Components/Widgets/AppHome/AppHome.dart';
import 'package:textreader/Provider/ImageProvider/ImageProvider.dart';
import 'package:textreader/Provider/SelectFileDetailProvider/SelectFileDetailProvider.dart';
import 'package:textreader/Services/SelectPdfToText/SelectPdfToText.dart';
import 'package:textreader/Services/galleryOrCamerImageToText/galleryOrCameraImageToText.dart';
import 'package:textreader/Utils/Constants/AssetConstants.dart';
import 'package:textreader/Utils/Constants/ColorConstants.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';

class AppHomeUI extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Consumer2<SelectFileDetailProvider, GetImageProvider>(
        builder: (context, selectFileDetailProvider, getImageProvider, child) {
      return WillPopScope(
        onWillPop: () async {
          selectFileDetailProvider.reset();
          getImageProvider.reset();
          return true;
        },
        child: ModalProgressHUD(
            inAsyncCall: selectFileDetailProvider.isLoading,
            dismissible: false,
            progressIndicator: AppLoader(),
            child: Scaffold(
              backgroundColor: ColorConstants.grey,
              body: SafeArea(
                child: Column(
                  children: [
                    AppHeader(
                      bodyText: "4Text2Speech",
                    ),
                    Expanded(
                        child: Column(
                      mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                      children: [
                        selectFileDetailProvider.fileName != ""
                            ? Padding(
                                // if filename available
                                padding:
                                    const EdgeInsets.fromLTRB(20, 0, 20, 0),
                                child: Center(
                                    child: Text(
                                  selectFileDetailProvider.fileName ?? "",
                                  textAlign: TextAlign.center,
                                  maxLines: 1,
                                  overflow: TextOverflow.ellipsis,
                                  style: TextStyle(
                                      fontSize: 20,
                                      color: ColorConstants.white),
                                )),
                              )
                            : Container(),
                        AppHome(
                          image: AssetConstants.gallery,
                          onPressed: () => galleryOrCameraImageToText().imgFrom(
                            ImageSource.gallery,
                            context,
                          ),
                        ),
                        AppHome(
                          image: AssetConstants.camera,
                          onPressed: () => galleryOrCameraImageToText().imgFrom(
                            ImageSource.camera,
                            context,
                          ),
                        ),
                        AppHome(
                          image: AssetConstants.file,
                          onPressed: () =>
                              SelectPdfToText.selectPdfToText(context),
                        ),
                      ],
                    ))
                  ],
                ),
              ),
            )),
      );
    });
  }
}
