import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:textreader/Components/AppHeader/AppHeader.dart';
import 'package:textreader/Components/Buttons/FilledButton.dart';
import 'package:textreader/Components/showToast/showToast.dart';
import 'package:textreader/Provider/ImageProvider/ImageProvider.dart';
import 'package:textreader/Provider/SelectFileDetailProvider/SelectFileDetailProvider.dart';
import 'package:text_to_speech/text_to_speech.dart';
import 'package:textreader/Utils/Constants/ColorConstants.dart';
import 'package:textreader/Utils/Constants/IconConstants.dart';
import 'package:textreader/Utils/Constants/NameConstants.dart';

class TextDetailandSpeechUI extends StatefulWidget {
  @override
  State<TextDetailandSpeechUI> createState() => _TextDetailandSpeechUIState();
}

class _TextDetailandSpeechUIState extends State<TextDetailandSpeechUI> {
  TextToSpeech tts = TextToSpeech();

  final String defaultLanguage = 'en-US';
  bool play = false;
  double volume = 1;
  double rate = 1.0;
  double pitch = 1.0;
  String language;

  String languageCode;

  List<String> languages = <String>[];

  List<String> languageCodes = <String>[];

  String voice;

  bool get supportPause => defaultTargetPlatform != TargetPlatform.android;

  bool get supportResume => defaultTargetPlatform != TargetPlatform.android;

  Future<void> speak(String text) async {
    setState(() {
      play = true;
    });
    tts.setVolume(volume);
    tts.setRate(rate);
    if (languageCode != null) {
      tts.setLanguage(languageCode);
    }
    tts.setPitch(pitch);
    tts.speak(text);
  }

  // onBoardingSpeak(String text) async {
  //   setState(() {
  //     play = true;
  //   });
  //   tts.setVolume(volume);
  //   tts.setRate(rate);
  //   if (languageCode != null) {
  //     tts.setLanguage(languageCode);
  //   }
  //   tts.setPitch(pitch);
  //   tts.speak(text);
  // }

  Future<void> initLanguages() async {
    /// populate lang code (i.e. en-US)
    languageCodes = await tts.getLanguages();

    /// populate displayed language (i.e. English)
    final List<String> displayLanguages = await tts.getDisplayLanguages();
    if (displayLanguages == null) {
      return;
    }

    languages.clear();
    for (final dynamic lang in displayLanguages) {
      languages.add(lang as String);
    }

    final String defaultLangCode = await tts.getDefaultLanguage();
    if (defaultLangCode != null && languageCodes.contains(defaultLangCode)) {
      languageCode = defaultLangCode;
    } else {
      languageCode = defaultLanguage;
    }
    language = await tts.getDisplayLanguageByCode(languageCode);

    /// get voice
    voice = await getVoiceByLang(languageCode);
    print(voice);

    if (mounted) {
      setState(() {});
    }
  }

  Future<String> getVoiceByLang(String lang) async {
    final List<String> voices = await tts.getVoiceByLang(languageCode);
    if (voices != null && voices.isNotEmpty) {
      return voices.first;
    }
    return null;
  }

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    WidgetsBinding.instance?.addPostFrameCallback((_) {
      initLanguages();
    });
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Consumer2<SelectFileDetailProvider, GetImageProvider>(
        builder: (context, selectFileDetailProvider, getImageProvider, child) {
      return WillPopScope(
        onWillPop: () async {
          selectFileDetailProvider.reset();
          getImageProvider.reset();
          setState(() {
            play = false;
            tts.stop();
          });
          return true;
        },
        child: Scaffold(
          backgroundColor: ColorConstants.grey,
          body: SafeArea(
            child: Column(
              children: [
                AppHeader(
                  bodyText: NameConstants.appName,
                  backButton: true,
                  onPressed: () {
                    Navigator.of(context).pop();
                    selectFileDetailProvider.reset();
                    getImageProvider.reset();
                    setState(() {
                      play = false;
                      tts.stop();
                    });
                  },
                ),
                Expanded(
                    child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    Padding(
                      padding: const EdgeInsets.all(12.0),
                      child: Container(
                        height: size.height * 0.4,
                        width: double.infinity,
                        decoration: BoxDecoration(
                            borderRadius: BorderRadius.all(Radius.circular(15)),
                            border: Border.all(
                                color: ColorConstants.appHeaderColor,
                                width: 2)),
                        child: getImageProvider.selectImage != null
                            ? ClipRRect(
                                borderRadius:
                                    BorderRadius.all(Radius.circular(15)),
                                child: Image.file(
                                  getImageProvider.selectImage,
                                  fit: BoxFit.cover,
                                ),
                              )
                            : SingleChildScrollView(
                                child: Padding(
                                  padding: const EdgeInsets.all(12.0),
                                  child: Text(
                                    selectFileDetailProvider.scanText ?? "",
                                    textAlign: TextAlign.center,
                                    style: TextStyle(
                                        color: ColorConstants.white,
                                        fontSize: 18),
                                  ),
                                ),
                              ),
                      ),
                    ),
                    // Row(
                    //   children: <Widget>[
                    //     const Text('Volume'),
                    //     Expanded(
                    //       child: Slider(
                    //         value: volume,
                    //         activeColor: ColorConstants.appButtonColor,
                    //         min: 0,
                    //         max: 1,
                    //         label: volume.round().toString(),
                    //         onChanged: (double value) {
                    //           initLanguages();
                    //           setState(() {
                    //             volume = value;
                    //           });
                    //         },
                    //       ),
                    //     ),
                    //     Text('(${volume.toStringAsFixed(2)})'),
                    //   ],
                    // ),
                    // Row(
                    //   children: <Widget>[
                    //     const Text('Rate'),
                    //     Expanded(
                    //       child: Slider(
                    //         value: rate,
                    //         activeColor: ColorConstants.appButtonColor,
                    //         min: 0,
                    //         max: 2,
                    //         label: rate.round().toString(),
                    //         onChanged: (double value) {
                    //           setState(() {
                    //             rate = value;
                    //           });
                    //         },
                    //       ),
                    //     ),
                    //     Text('(${rate.toStringAsFixed(2)})'),
                    //   ],
                    // ),
                    // Row(
                    //   children: <Widget>[
                    //     const Text('Pitch'),
                    //     Expanded(
                    //       child: Slider(
                    //         value: pitch,
                    //         activeColor: ColorConstants.appButtonColor,
                    //         min: 0,
                    //         max: 2,
                    //         label: pitch.round().toString(),
                    //         onChanged: (double value) {
                    //           setState(() {
                    //             pitch = value;
                    //           });
                    //         },
                    //       ),
                    //     ),
                    //     Text('(${pitch.toStringAsFixed(2)})'),
                    //   ],
                    // ),
                    InkWell(
                      onTap: () {
                        if (play) {
                          setState(() {
                            play = false;
                            tts.stop();
                            showToast('Speech Stop');
                          });
                        } else {
                          speak(selectFileDetailProvider.scanText);
                          showToast('Text Load To Speech');
                        }
                      },
                      child: Container(
                          height: 60,
                          width: 150,
                          decoration: BoxDecoration(
                              color: ColorConstants.black,
                              borderRadius:
                                  BorderRadius.all(Radius.circular(12))),
                          child: Center(
                              child: Text(
                            play ? "Stop" : "Read out loud",
                            style: TextStyle(color: ColorConstants.white),
                          ))
                          // IconButton(
                          //   color: ColorConstants.white,
                          //   onPressed: () {
                          //     if (play) {
                          //       setState(() {
                          //         play=false;
                          //         tts.stop();
                          //       });
                          //     } else {
                          //       speak(selectFileDetailProvider.scanText);
                          //     }
                          //   },
                          //   icon: Icon(play ? Icons.pause : Icons.play_arrow),
                          // ),
                          ),
                    ),
                    SizedBox(
                      height: 10,
                    ),
                    // Row(
                    //   children: <Widget>[
                    //     Expanded(
                    //       child: Container(
                    //         padding: const EdgeInsets.only(right: 10),
                    //         child: ElevatedButton(
                    //           child: const Text('Stop'),
                    //           onPressed: () {
                    //             tts.stop();
                    //           },
                    //         ),
                    //       ),
                    //     ),
                    //     if (supportPause)
                    //       Expanded(
                    //         child: Container(
                    //           padding: const EdgeInsets.only(right: 10),
                    //           child: ElevatedButton(
                    //             child: const Text('Pause'),
                    //             onPressed: () {
                    //               tts.pause();
                    //             },
                    //           ),
                    //         ),
                    //       ),
                    //     if (supportResume)
                    //       Expanded(
                    //         child: Container(
                    //           padding: const EdgeInsets.only(right: 10),
                    //           child: ElevatedButton(
                    //             child: const Text('Resume'),
                    //             onPressed: () {
                    //               tts.resume();
                    //             },
                    //           ),
                    //         ),
                    //       ),
                    //     Expanded(
                    //         child: Container(
                    //       child: ElevatedButton(
                    //         child: const Text('Speak'),
                    //         onPressed: () {
                    //           speak(selectFileDetailProvider.scanText);
                    //         },
                    //       ),
                    //     ))
                    //   ],
                    // )
                  ],
                ))
              ],
            ),
          ),
        ),
      );
    });
  }
}
