import 'package:flutter/material.dart';
import 'package:textreader/Components/Buttons/FilledButton.dart';
import 'package:textreader/Model/onBoardingModel/onBoardingModel.dart';
import 'package:textreader/Services/SharedPreferenceService/SharedPreferencesService.dart';
import 'package:textreader/Utils/Constants/ColorConstants.dart';
import 'package:textreader/Utils/Constants/ConstantValue.dart';
import 'package:textreader/Utils/Constants/KeysConstants.dart';
import 'package:textreader/Utils/Constants/RouteConstants.dart';

class OnBoardingScreenUI extends StatefulWidget {
  @override
  _OnBoardingScreenUIState createState() => _OnBoardingScreenUIState();
}

class _OnBoardingScreenUIState extends State<OnBoardingScreenUI> {
  int currentIndex = 0;
  PageController _controller;

  @override
  void initState() {
    _controller = PageController(initialPage: 0);
    super.initState();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    Size size=MediaQuery.of(context).size;
    return Scaffold(
      backgroundColor:ColorConstants.grey,
      appBar: AppBar(
        elevation: 0,
        backgroundColor: ColorConstants.transparent,
        actions: [
          TextButton(
              onPressed: () async {
                Navigator.of(context).pushNamedAndRemoveUntil(
                    RouteConstants.appHomeUI, (Route<dynamic> route) => false);
                await SharedPreferencesService().setString(KeysConstants.userLogin, 'yes');
            },

              child: Text(
                "SKIP",
                style: TextStyle(fontSize: 18, color: ColorConstants.white),
              ))
        ],
      ),
      body: Column(
        children: [
          Expanded(
            child: PageView.builder(
              controller: _controller,
              itemCount: onBoardingData.length,
              onPageChanged: (int index) {
                setState(() {
                  currentIndex = index;
                });
              },
              itemBuilder: (_, i) {
                return Padding(
                  padding: const EdgeInsets.all(40),
                  child: Column(
                    mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                    children: [
                      Image.asset(
                        onBoardingData[i].onBoardingImage,
                        scale: 3.5,
                      ),
                      // Text(
                      //   onBoardingData[i].onBoardingTitle,
                      //   style: TextStyle(
                      //     fontSize: 18,
                      //     fontWeight: FontWeight.bold,
                      //   ),
                      // ),
                      SizedBox(height: 10),
                      Text(
                        onBoardingData[i].onBoardingDescription,
                        textAlign: TextAlign.center,
                        style: TextStyle(
                          fontSize: 17,
                          color: Colors.white,
                        ),
                      )
                    ],
                  ),
                );
              },
            ),
          ),
          Container(
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: List.generate(
                onBoardingData.length,
                (index) => buildDot(index, context),
              ),
            ),
          ),
          SizedBox(
           height: 15
          ),
          FilledButton(
            width: size.width*0.8,
            height:50,
            title:
                currentIndex == onBoardingData.length - 1 ? "Continue" : "Next",
            onPressed: () async {
              if (currentIndex == onBoardingData.length - 1) {
                Navigator.of(context).pushNamedAndRemoveUntil(
                    RouteConstants.appHomeUI, (Route<dynamic> route) => false);
                await SharedPreferencesService().setString(KeysConstants.userLogin, 'yes');
              }
              _controller.nextPage(
                duration: Duration(milliseconds: 100),
                curve: Curves.bounceIn,
              );
            },
          ),
          SizedBox(
              height: 15
          ),
        ],
      ),
    );
  }

  Container buildDot(int index, BuildContext context) {
    return Container(
      height: 10,
      width: currentIndex == index ? 25 : 10,
      margin: EdgeInsets.only(right: 5),
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(20),
        color: ColorConstants.white,
      ),
    );
  }
}
