import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:provider/provider.dart';
import 'package:textreader/Provider/ImageProvider/ImageProvider.dart';
import 'package:textreader/Provider/SelectFileDetailProvider/SelectFileDetailProvider.dart';
import 'package:textreader/Utils/Constants/ColorConstants.dart';
import 'package:textreader/Utils/Constants/NameConstants.dart';
import 'Routes/Routes.dart';
import 'Utils/Constants/RouteConstants.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  SystemChrome.setPreferredOrientations([
    DeviceOrientation.portraitDown,
    DeviceOrientation.portraitUp,
  ]);
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return ScreenUtilInit(
        designSize: Size(360, 690),
        minTextAdapt: true,
        splitScreenMode: true,
        builder: () => MultiProvider(
              providers: [
                ChangeNotifierProvider<SelectFileDetailProvider>(
                  create: (context) => SelectFileDetailProvider(),
                ),
                ChangeNotifierProvider<GetImageProvider>(
                  create: (context) => GetImageProvider(),
                ),
              ],
              child: MaterialApp(
                title: NameConstants.appName,
                theme: ThemeData(
                  fontFamily: 'fontStyle',
                  primarySwatch: kPrimaryColor,
                ),
                debugShowCheckedModeBanner: false,
                initialRoute: RouteConstants.initialRoute,
                onGenerateRoute: RouteGenerator.generateRoute,
              ),
            ));
  }
}

const MaterialColor kPrimaryColor = const MaterialColor(
  0XFF03045e,
  const <int, Color>{
    50: ColorConstants.appPrimaryColor,
    100: ColorConstants.appPrimaryColor,
    200: ColorConstants.appPrimaryColor,
    300: ColorConstants.appPrimaryColor,
    400: ColorConstants.appPrimaryColor,
    500: ColorConstants.appPrimaryColor,
    600: ColorConstants.appPrimaryColor,
    700: ColorConstants.appPrimaryColor,
    800: ColorConstants.appPrimaryColor,
    900: ColorConstants.appPrimaryColor,
  },
);
